| Title: | Obtain 'jQuery' as an HTML Dependency Object |
|---|---|
| Description: | Obtain any major version of 'jQuery' (<https://code.jquery.com/>) and use it in any webpage generated by 'htmltools' (e.g. 'shiny', 'htmlwidgets', and 'rmarkdown'). Most R users don't need to use this package directly, but other R packages (e.g. 'shiny', 'rmarkdown', etc.) depend on this package to avoid bundling redundant copies of 'jQuery'. |
| Authors: | Carson Sievert [aut, cre]
|
| Maintainer: | Carson Sievert <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.4 |
| Built: | 2026-06-10 09:28:36 UTC |
| Source: | https://github.com/cran/jquerylib |
Obtain jQuery Core as an HTML dependency
jquery_core(major_version = 3, minified = getOption("shiny.minified", TRUE))jquery_core(major_version = 3, minified = getOption("shiny.minified", TRUE))
major_version |
The major version of jQuery Core. Currrently 1, 2, and 3 are supported. |
minified |
whether or not to provide a minified JavaScript file. |
A htmltools::htmlDependency() object.